@@ -1,7 +1,7 @@
 # __init__.py - main module
 # coding: utf-8
 #
-# Copyright (C) 2014-2017 Arthur de Jong
+# Copyright (C) 2014-2019 Arthur de Jong
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -18,7 +18,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Python module for handling PSKC files
+"""Python module for handling PSKC files.
 
 This Python library handles Portable Symmetric Key Container (PSKC) files as
 defined in RFC 6030. PSKC files are used to transport and provision symmetric
@@ -54,7 +54,7 @@ __all__ = ['PSKC', '__version__']
 
 
 # the version number of the library
-__version__ = '1.0'
+__version__ = '1.1'
 
 
 class PSKC(object):
@@ -95,29 +95,24 @@ class PSKC(object):
         """Create a new device instance for the PSKC file.
 
         The device is initialised with properties from the provided keyword
-        arguments if any."""
-        from pskc.device import Device
+        arguments if any.
+        """
+        from pskc.device import Device, update_attributes
         device = Device(self)
         self.devices.append(device)
-        # assign the kwargs as key properties
-        for k, v in kwargs.items():
-            if not hasattr(device, k):
-                raise AttributeError()
-            setattr(device, k, v)
+        update_attributes(device, **kwargs)
         return device
 
     def add_key(self, **kwargs):
         """Create a new key instance for the PSKC file.
 
         The new key is initialised with properties from the provided keyword
-        arguments if any."""
+        arguments if any.
+        """
+        from pskc.device import update_attributes
         device = self.add_device()
         key = device.add_key()
-        # assign the kwargs as key properties
-        for k, v in kwargs.items():
-            if not hasattr(key, k):
-                raise AttributeError()
-            setattr(key, k, v)
+        update_attributes(key, **kwargs)
         return key
 
     def write(self, filename):
