@@ -1,7 +1,7 @@
 # encryption.py - module for handling encrypted values
 # coding: utf-8
 #
-# Copyright (C) 2014-2017 Arthur de Jong
+# Copyright (C) 2014-2018 Arthur de Jong
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -211,6 +211,7 @@ class KeyDerivation(object):
         self._pbkdf2_prf = normalise_algorithm(value)
 
     def derive_pbkdf2(self, password):
+        """Derive an encryption key from the provided password."""
         from hashlib import pbkdf2_hmac
         from pskc.exceptions import KeyDerivationError
         prf = 'sha1'
@@ -249,6 +250,7 @@ class KeyDerivation(object):
 
     def setup_pbkdf2(self, password, salt=None, salt_length=16,
                      key_length=None, iterations=None, prf=None):
+        """Configure PBKDF2 key derivation properties."""
         self.algorithm = 'pbkdf2'
         if salt is None:
             salt = os.urandom(salt_length)
@@ -256,7 +258,7 @@ class KeyDerivation(object):
         if iterations:
             self.pbkdf2_iterations = iterations
         elif self.pbkdf2_iterations is None:
-            self.pbkdf2_iterations = 12 * 1000
+            self.pbkdf2_iterations = 100000
         if key_length:  # pragma: no branch (always specified)
             self.pbkdf2_key_length = key_length
         if prf:
@@ -340,7 +342,7 @@ class Encryption(object):
             self.algorithm = 'aes128-cbc'
         # default to encrypting the secret only
         if not self.fields:
-            self.fields = ['secret', ]
+            self.fields = ['secret']
         # if we're using a CBC mode of encryption, add a MAC
         if self.algorithm.endswith('-cbc'):
             self.pskc.mac.setup()
@@ -402,4 +404,33 @@ class Encryption(object):
 
     def encrypt_value(self, plaintext):
         """Encrypt the provided value and return the cipher_value."""
-        return encrypt(self.algorithm, self.key, plaintext, self.iv)
+        cipher_value = encrypt(self.algorithm, self.key, plaintext, self.iv)
+        if self.iv:
+            cipher_value = cipher_value[len(self.iv):]
+        return cipher_value
+
+    def remove_encryption(self):
+        """Decrypt all values and remove the encryption from the PSKC file."""
+        # decrypt all values and store decrypted values
+        for key in self.pskc.keys:
+            key.secret = key.secret
+            key.counter = key.counter
+            key.time_offset = key.time_offset
+            key.time_interval = key.time_interval
+            key.time_drift = key.time_drift
+        # remove MAC configuration
+        self.pskc.mac.algorithm = None
+        self.pskc.mac.key = None
+        # remove encryption configuration
+        self.id = None
+        self.algorithm = None
+        self.key_names = []
+        self.key = None
+        self.iv = None
+        self.fields = []
+        # remove key derivation configuration
+        self.derivation.algorithm = None
+        self.derivation.pbkdf2_salt = None
+        self.derivation.pbkdf2_iterations = None
+        self.derivation.pbkdf2_key_length = None
+        self.derivation.pbkdf2_prf = None
